==> jc-1.4.0.tar.gz: soot/toolkits/scalar/FastColorer.h <==
// public class soot.toolkits.scalar.FastColorer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4e868c13fc5803c6 soot_toolkits_scalar_FastColorer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_FastColorer_H_
#define _JC_soot_toolkits_scalar_FastColorer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FastColorer$sub_refs	_jc_soot_toolkits_scalar_FastColorer$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs	_jc_soot_toolkits_scalar_FastColorer$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$refs	_jc_soot_toolkits_scalar_FastColorer$refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$nonrefs	_jc_soot_toolkits_scalar_FastColorer$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$object	_jc_soot_toolkits_scalar_FastColorer$object;

typedef const struct _jc_soot_toolkits_scalar_FastColorer$vmethods	_jc_soot_toolkits_scalar_FastColorer$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FastColorer$vtable	_jc_soot_toolkits_scalar_FastColorer$vtable;
typedef const struct _jc_soot_toolkits_scalar_FastColorer$vtype	_jc_soot_toolkits_scalar_FastColorer$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FastColorer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer$object *);

// Static methods
extern void _jc_soot_toolkits_scalar_FastColorer$method$assignColorsToLocals$ded8037af20b1e22(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_toolkits_scalar_FastColorer$method$unsplitAssignColorsToLocals$2357be4caf9a1fbe(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FastColorer$vmethods {
};

// Vtable
struct _jc_soot_toolkits_scalar_FastColorer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_FastColorer$vmethods	soot_toolkits_scalar_FastColorer;
};

// Vtype
struct _jc_soot_toolkits_scalar_FastColorer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FastColorer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer$refs {
    _jc_soot_toolkits_scalar_FastColorer$sub_refs	soot_toolkits_scalar_FastColorer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs	soot_toolkits_scalar_FastColorer;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FastColorer$object {
	_jc_soot_toolkits_scalar_FastColorer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FastColorer$vtype	*vtype;
	_jc_soot_toolkits_scalar_FastColorer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FastColorer$vtype _jc_soot_toolkits_scalar_FastColorer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FastColorer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FastColorer$class_object;

#endif	/* _JC_soot_toolkits_scalar_FastColorer_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/FastColorer.h <==
// public class soot.toolkits.scalar.FastColorer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4e868c13fc5803c6 soot_toolkits_scalar_FastColorer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_FastColorer_H_
#define _JC_soot_toolkits_scalar_FastColorer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FastColorer$sub_refs	_jc_soot_toolkits_scalar_FastColorer$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs	_jc_soot_toolkits_scalar_FastColorer$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$refs	_jc_soot_toolkits_scalar_FastColorer$refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$nonrefs	_jc_soot_toolkits_scalar_FastColorer$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer$object	_jc_soot_toolkits_scalar_FastColorer$object;

typedef const struct _jc_soot_toolkits_scalar_FastColorer$vmethods	_jc_soot_toolkits_scalar_FastColorer$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FastColorer$vtable	_jc_soot_toolkits_scalar_FastColorer$vtable;
typedef const struct _jc_soot_toolkits_scalar_FastColorer$vtype	_jc_soot_toolkits_scalar_FastColorer$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FastColorer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_toolkits_scalar_FastColorer$method$assignColorsToLocals$ded8037af20b1e22(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_FastColorer$method$unsplitAssignColorsToLocals$2357be4caf9a1fbe(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FastColorer$vmethods {
};

// Vtable
struct _jc_soot_toolkits_scalar_FastColorer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_FastColorer$vmethods	soot_toolkits_scalar_FastColorer;
};

// Vtype
struct _jc_soot_toolkits_scalar_FastColorer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FastColorer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer$refs {
    _jc_soot_toolkits_scalar_FastColorer$sub_refs	soot_toolkits_scalar_FastColorer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_FastColorer$sub_nonrefs	soot_toolkits_scalar_FastColorer;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FastColorer$object {
	_jc_soot_toolkits_scalar_FastColorer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FastColorer$vtype	*vtype;
	_jc_soot_toolkits_scalar_FastColorer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FastColorer$vtype _jc_soot_toolkits_scalar_FastColorer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FastColorer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FastColorer$class_object;

#endif	/* _JC_soot_toolkits_scalar_FastColorer_H_ */
